Office suite document core.
Re-exports
pub use caps::CREDENTIALS_CAPABILITY;pub use caps::NET_CONNECT_CAPABILITY;pub use caps::OfficeCapabilityProfile;pub use caps::PROCESS_SPAWN_CAPABILITY;pub use caps::WALL_CLOCK_CAPABILITY;pub use edit::DomainEdit;pub use edit::Edit;pub use edit::invert;pub use error::OfficeError;pub use evidence::Evidence;pub use evidence::LinkRole;pub use fidelity::FidelityReport;pub use fidelity::LossNote;pub use model::DOC_KIND_ARTICLE;pub use model::DOC_KIND_README;pub use model::DOC_KIND_REPORT;pub use model::Doc;pub use model::DocId;pub use model::DocKind;pub use model::ExternalRef;pub use place::DocCodec;pub use place::DocCodecOptions;pub use place::DocSite;pub use place::Placement;pub use projection::ProjectionCaps;pub use projection::ProjectionRequest;pub use projection::SurfaceCaps;pub use projection::TAG_BACKEND;pub use projection::TAG_FIDELITY;pub use projection::TAG_LENS;pub use projection::TAG_STATEMENT_KIND;pub use projection::TAG_TARGET;pub use projection::project;pub use shape::DocKindShape;pub use shape::doc_shape;pub use zip_package::ZipLimits;pub use zip_package::read_zip_entries;
Modules
- caps
- Capability profile for office document placements.
- edit
- Open reversible edit contract for document domains.
- error
- Error type shared by the office document core.
- evidence
- Cross-object evidence links between office documents and external records.
- fidelity
- Fidelity reporting for file codecs and service placements.
- model
- Plain document records shared by office codecs, stores, views, and sites.
- place
- Placement contracts for document codecs and service sites.
- projection
- Projection selection for office documents.
- shape
- Shape values for open document kinds.
- zip_
package - Bounded ZIP package extraction for office codecs.
Statics
- RECIPES
- Cookbook recipes for this lib, embedded at build time.