Plain document records shared by office codecs, stores, views, and sites.
Structs
- Doc
- An office-family document carried as runtime data.
- DocId
- Stable document identifier.
- DocKind
- Open document kind name.
- External
Ref - Reference to an external file, service object, row, task, or source record.
Constants
- DOC_
KIND_ ARTICLE - Prose article document kind reserved by the office core vocabulary.
- DOC_
KIND_ README - Readme document kind reserved by the office core vocabulary.
- DOC_
KIND_ REPORT - Prose report document kind reserved by the office core vocabulary.