Module projection

Module projection 

Projection selection for office documents.

Structs

ProjectionCaps
Open projection capabilities.
ProjectionRequest
A request to project one document for one capability set.

Constants

TAG_BACKEND
Open tag key for a preferred backend or file/service family.
TAG_FIDELITY
Open tag key for the requested fidelity level.
TAG_LENS
Open tag key for a preferred document lens.
TAG_STATEMENT_KIND
Open tag key for statement-specific projections.
TAG_TARGET
Open tag key for the intended surface or export target.

Functions

project
Project a document to a deterministic runtime value for the requested caps.

Type Aliases

SurfaceCaps
Office projection caps are surface-cap metadata carried as open tags.