pub fn project(
cx: &mut Cx,
req: &ProjectionRequest<'_>,
) -> Result<Value, OfficeError>Expand description
Project a document to a deterministic runtime value for the requested caps.
pub fn project(
cx: &mut Cx,
req: &ProjectionRequest<'_>,
) -> Result<Value, OfficeError>Project a document to a deterministic runtime value for the requested caps.