Module shape

Module shape 

Shape values for open document kinds.

Structs

DocKindShape
A shape that accepts Doc values with one open DocKind.

Functions

doc_shape
Build a kernel shape value for one open document kind.